@@ -3,7 +3,7 @@ from enum import Enum
 from types import SimpleNamespace
 from typing import List
 
-LANGUAGES = {'cpp': 'C++', 'cs': 'C#', 'c': 'C', 'py': 'Python'}
+LANGUAGES = {'cpp': 'C++', 'cs': 'C#', 'c': 'C', 'py': 'Python', 'rb': 'Ruby'}
 
 COMPILE_COMMANDS = {
     'cs': lambda filename: ['mcs', '-optimize', '-nologo', '-out:' + filename + '.o', filename],
@@ -11,6 +11,7 @@ COMPILE_COMMANDS = {
     'c': lambda filename: ['gcc', '-x', 'c++', '-o', filename + '.o', filename],
     'py': lambda filename: [['pylint', '--disable=R,C', filename], ['cp', filename, filename + '.o']],
     'py_nl': lambda filename: ['cp', filename, filename + '.o'],
+    'rb': lambda filename: ['cp', filename, filename + '.o'],
 }
 EXEC_COMMANDS = {
     'cs': lambda filename: ['mono', filename],
@@ -18,6 +19,7 @@ EXEC_COMMANDS = {
     'c': lambda filename: [filename],
     'py': lambda filename: ['python3', filename],
     'py_nl': lambda filename: ['python3', filename],
+    'rb': lambda filename: ['ruby', filename],
 }
 AVAILABLE_BINARIES = {
     'cs': ['env', 'bash', 'sh', 'mono', 'mcs'],
@@ -25,6 +27,7 @@ AVAILABLE_BINARIES = {
     'c': ['env', 'bash', 'sh', 'gcc', 'ld', 'as'],
     'py': ['env', 'bash', 'sh', 'python', 'python3', 'pylint', 'cp'],
     'py_nl': ['env', 'bash', 'sh', 'python', 'python3', 'cp'],
+    'rb': ['env', 'bash', 'sh', 'ruby', 'cp'],
 }
 
 MY_USER = getpass.getuser()
